## Описание

`uploadtodalas` — это простой пакет для загрузки файлов на сервис Dalas. Он поддерживает асинхронную и синхронную загрузку файлов. Пакет включает методы как для панелей, так и для простых пользователей.

## Установка

Вы можете установить этот пакет с помощью pip:

Для Windows:
```bash
pip install uploadtodalas
```

Для Linux:
```bash
pip3 install uploadtodalas
```

## Пример использования

Ниже приведены примеры использования различных функций, доступных в пакете `uploadtodalas`.


>**Все функции, доступные в пакете `uploadtodalas`, имеют внутрикодовую документацию, пажалуйста ознакомьтесь с ней, а также с документацией изложенной на апи ресурсах. [Пользователям](https://api.uploadgroup.site/docs), [Панелям](https://api.dalas.pw/docs)**

### Инициализация клиента

Для начала работы необходимо создать экземпляр класса `UploadToDalas` и передать API ключ (если он у вас есть):

```python
from uploadtodalas.upload import UploadToDalas

client = UploadToDalas(api_key='ваш_api_ключ')  # API ключ необходим только для панелей
client = UploadToDalas()  # Инициализация без API ключа
```

### Асинхронная загрузка файла
<details>
  <summary>*</summary>
  Для начала работы необходимо создать экземпляр класса `UploadToDalas` и передать API ключ (если он у вас есть). Смотрите раздел `Инициализация клиента`. 
</details>

Метод загрузки файлов, только .zip и .rar
```python
import asyncio

async def main():
    await client.AsyncUploadToDalas(file_path='/path/to/your/file.zip', seller_id=1111, shedul_in_hours=0)

asyncio.run(main())
```

### Синхронная загрузка файла
<details>
  <summary>*</summary>
  Для начала работы необходимо создать экземпляр класса `UploadToDalas` и передать API ключ (если он у вас есть). Смотрите раздел `Инициализация клиента`. 
</details>

Метод загрузки файлов, только .zip и .rar
```python
client.SyncUploadToDalas(file_path='/path/to/your/file.zip', seller_id=1111, shedul_in_hours=0)
```

### Пример использования методов для панелей
>**Все функции, доступные в пакете `uploadtodalas`, имеют внутрикодовую документацию, пажалуйста ознакомьтесь с ней, а также с документацией изложенной на апи ресурсах. [Пользователям](https://api.uploadgroup.site/docs), [Панелям](https://api.dalas.pw/docs)**
<details>
  <summary>*</summary>
  Для начала работы необходимо создать экземпляр класса `UploadToDalas` и передать API ключ (если он у вас есть). Смотрите раздел `Инициализация клиента`. 
</details>

Метод загрузки файлов, только .zip и .rar
```python
import asyncio

async def main():
    seller_id = await client.PannelAsyncGetId(telegram_id=123456789) # Получение seller_id по телеграм ид.
    if seller_id:
        await client.PannelAsyncUpload(file_path='/path/to/your/file.zip', seller_id=seller_id, shedul_in_hours=0, strict=True)

asyncio.run(main())
```
<details>
  <summary>*</summary>
  Для начала работы необходимо создать экземпляр класса `UploadToDalas` и передать API ключ (если он у вас есть). Смотрите раздел `Инициализация клиента`. 
</details>

Метод запроса выплаты
```python
import asyncio

async def main():
    seller_id = await client.PannelAsyncGetId(telegram_id=123456789) # Получение seller_id по телеграм ид.
    if seller_id:
        await client.PannelAsyncPayOff(seller_id=seller_id, strict=True)

asyncio.run(main())
```
